@@ -4,14 +4,13 @@ import os
 import colorama
 from pathlib import Path
 import pathlib
+from rc.utils.raga_config_reader import read_raga_config, get_config_value as raga_config
 
+config_data = read_raga_config()
+rc_base_url = raga_config(config_data, 'default', 'rc_base_url')
+RC_BASE_URL = rc_base_url
 
-BASE_URL = 'http://ec2-13-127-105-156.ap-south-1.compute.amazonaws.com:8092/v1/api'
 DEBUG = False
-RCTL_PATH = '.rctl'
-RCTL_LOG_PATH = f'{RCTL_PATH}/logs'
-RCTL_LOG_FILE = f'{RCTL_LOG_PATH}/rctl.log'
-
 
 def format_link(link):
     return "<{blue}{link}{nc}>".format(
